@@ -1,7 +1,7 @@
 #*********************************************************************
 #*** ResourcePool
 #*** Copyright (c) 2002,2003 by Markus Winand <mws@fatalmind.com>
-#*** $Id: ResourcePool.pm,v 1.49.2.1 2003/03/27 20:35:58 mws Exp $
+#*** $Id: ResourcePool.pm,v 1.49.2.3 2003/05/07 19:40:11 mws Exp $
 #*********************************************************************
 
 ######
@@ -26,7 +26,7 @@ BEGIN {
 
 
 push @ISA, ("ResourcePool::Command::Execute", "ResourcePool::Singleton");
-$VERSION = "1.0102";
+$VERSION = "1.0103";
  
 sub new($$@) {
 	my $proto = shift;
@@ -69,7 +69,7 @@ sub new($$@) {
 	
 		}
 		# truncate list if it is too long
-		$#{@{$options{SleepOnFail}}} = $options{MaxTry} - 2;
+		$#{$options{SleepOnFail}} = $options{MaxTry} - 2;
 		
 		$self->{Max}         = $options{Max};
 		$self->{Min}         = $options{Min};
